[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- object: The most base type
  - littletable.DataObject: A generic semi-mutable object for storing data values in a table.
  - littletable.JoinTerm: Temporary object created while composing a join across tables using Table.join_on and '+' addition.
  - littletable.Table: Table is the main class in `littletable`, for representing a collection of DataObjects or user-defined objects with publicly accessible attributes or properties.
    - littletable.PivotTable: Enhanced Table containing pivot results from calling table.pivot().